@@ -1,6 +1,6 @@
 package WWW::FetchStory::Fetcher::FanfictionNet;
 BEGIN {
-  $WWW::FetchStory::Fetcher::FanfictionNet::VERSION = '0.1302';
+  $WWW::FetchStory::Fetcher::FanfictionNet::VERSION = '0.14';
 }
 use strict;
 use warnings;
@@ -10,7 +10,7 @@ WWW::FetchStory::Fetcher::FanfictionNet - fetching module for WWW::FetchStory
 
 =head1 VERSION
 
-version 0.1302
+version 0.14
 
 =head1 DESCRIPTION
 
@@ -126,6 +126,7 @@ sub extract_story {
 	$para = $3;
 	$category =~ s!\s*\&\s!, !g;
 	$characters =~ s!\s*\&\s!, !g;
+
     }
     warn "category=$category\n" if $self->{verbose};
     warn "characters=$characters\n" if $self->{verbose};
@@ -354,6 +355,18 @@ sub parse_characters {
 	$category =~ s!\s*\&\s!, !g;
 	$characters =~ s!\s*\&\s!, !g;
 	$characters =~ s!\.!!g;
+
+	# Correct some character names
+	$characters =~ s/Hermione G/Hermione Granger/;
+	$characters =~ s/Severus S/Severus Snape/;
+	$characters =~ s/Harry P/Harry Potter/;
+	$characters =~ s/Draco M/Draco Malfoy/;
+	$characters =~ s/Remus L/Remus Lupin/;
+	$characters =~ s/Sirius B/Sirius Black/;
+	$characters =~ s/Alastor M/Alastor Moody/;
+	$characters =~ s/Ginny W/Ginny Weasley/;
+	$characters =~ s/Fred W/Fred Weasley/;
+	$characters =~ s/George W/George Weasley/;
     }
     else
     {
